LazyHorseFeed = {}

LazyHorseFeed.name = "LazyHorseFeed"
LazyHorseFeed.version = 1
local trainPriorities ={
	RIDING_TRAIN_SPEED,
	RIDING_TRAIN_CARRYING_CAPACITY,
	RIDING_TRAIN_STAMINA,
}
local trainNames = {
	[RIDING_TRAIN_SPEED] = "Speed",
	[RIDING_TRAIN_STAMINA] = "Stamina",
	[RIDING_TRAIN_CARRYING_CAPACITY] = "Capacity"
}

LazyHorseFeed.defaultCharacter = 
{
	["TrainOrder"] = {
		RIDING_TRAIN_SPEED,
		RIDING_TRAIN_CARRYING_CAPACITY,
		RIDING_TRAIN_STAMINA,
	},
	["useCharacterSettings"] = false,
}
LazyHorseFeed.default = {
	["accountWideProfile"] = LazyHorseFeed.defaultCharacter,
}


local panel =  
{
     type = "panel",
     name = "Lazy Horse Trainer",
     registerForRefresh = true,
     displayName = "|c8080FF Lazy Horse Trainer|r",
     author = "@Dolgubon"
}
local function shallowCopy (source, destination)
	for k, v in pairs(source) do
		destination[k] = v
	end
end
LazyHorseFeed.localizedStrings = {}
LazyHorseFeed.localizedStrings.SettingsStrings = {}


LazyHorseFeed.localizedStrings.SettingsStrings.nowEditing                   = "You are changing %s settings"
LazyHorseFeed.localizedStrings.SettingsStrings.accountWide                  = "Account Wide"
LazyHorseFeed.localizedStrings.SettingsStrings.characterSpecific            = "Character Specific"

LazyHorseFeed.localizedStrings.SettingsStrings.showAtStation 				= "Show at Station"
LazyHorseFeed.localizedStrings.SettingsStrings.showAtStationTooltip			= "Always show the Set Crafter UI at crafting stations"
LazyHorseFeed.localizedStrings.SettingsStrings.saveLastChoice				= "Save Choices"
LazyHorseFeed.localizedStrings.SettingsStrings.saveLastChoiceTooltip		= "Save the last selected choices"
LazyHorseFeed.localizedStrings.SettingsStrings.closeOnExit                  = "Close on Station Exit"
LazyHorseFeed.localizedStrings.SettingsStrings.closeOnExitTooltip           = "Close the Set Crafter UI when exiting a crafting station"
LazyHorseFeed.localizedStrings.SettingsStrings.useCharacterSettings         = "Use character settings" 
LazyHorseFeed.localizedStrings.SettingsStrings.useCharacterSettingsTooltip  = "Use character specific settings on this character only"
LazyHorseFeed.localizedStrings.SettingsStrings.showToggleButton              = "Always show toggle button"
LazyHorseFeed.localizedStrings.SettingsStrings.showToggleButtonTooltip       = "Show the UI toggle button at all times"

local SettingsStrings = LazyHorseFeed.localizedStrings.SettingsStrings

local options =
{
	{
		type = "header",
		name = function() 
			local profile = SettingsStrings.accountWide
			if LazyHorseFeed.charSavedVars.useCharacterSettings then
				profile = SettingsStrings.characterSpecific
			end
			return  string.format(SettingsStrings.nowEditing, profile)  
		end, -- or string id or function returning a string
	},
	{
		type = "checkbox",
		name = SettingsStrings.useCharacterSettings,
		tooltip = SettingsStrings.useCharacterSettingsTooltip,
		getFunc = function() return LazyHorseFeed.charSavedVars.useCharacterSettings end,
		setFunc = function(value) 
			LazyHorseFeed.charSavedVars.useCharacterSettings = value
		end,
	},
	{
		type = "divider",
		height = 15,
		alpha = 0.5,
		width = "full"
	},
	
}

function LazyHorseFeed:GetSettings()
	if LazyHorseFeed.charSavedVars.useCharacterSettings then
		return LazyHorseFeed.charSavedVars
	else
		return LazyHorseFeed.savedvars.accountWideProfile
	end
end

local function trainingReset()
	local date = {}
	local till = {}
	local day = 86400
	local hour = 3600
	local seconds = GetTimeUntilCanBeTrained()/1000
	local minutes = math.floor( seconds / 60)
	local hours = math.floor(minutes  / 60)
	minutes = minutes % 60
	d("Already trained today. "..hours.."h "..minutes.."m until you can train again")
end


local function HandleStableOpen()
	if GetTimeUntilCanBeTrained() > 0 then
		trainingReset()
		SCENE_MANAGER:Show('hud')
		return
	end
	if GetCurrencyAmount(CURT_MONEY, CURRENCY_LOCATION_CHARACTER) <250 then
		d("You do not have enough gold to train your riding skill")
		return
	end
	local inventoryBonus ,_,staminaBonus,_,speedBonus = GetRidingStats()
	local trainLevels = 
	{
		[RIDING_TRAIN_SPEED] = speedBonus,
		[RIDING_TRAIN_CARRYING_CAPACITY] = inventoryBonus,
		[RIDING_TRAIN_STAMINA] = staminaBonus,
	}
	for i = 1, #LazyHorseFeed:GetSettings().TrainOrder do
		if trainLevels[LazyHorseFeed:GetSettings().TrainOrder[i]]~=60 then
			TrainRiding(LazyHorseFeed:GetSettings().TrainOrder[i])
			d("Trained "..trainNames[LazyHorseFeed:GetSettings().TrainOrder[i]])
			SCENE_MANAGER:Show('hud')
			return
		end
	end
	d("Max training level already")
	SCENE_MANAGER:Show('hud')
end


local function HandleChatterBegin(eventCode, optionCount)
	for i = 1, optionCount do
		local optionString, optionType = GetChatterOption(i)
		if optionString == "View Stable" then
			SelectChatterOption(i)
		end
	end

end

function LazyHorseFeed:Initialize()
	EVENT_MANAGER:RegisterForEvent(LazyHorseFeed.name, EVENT_CHATTER_BEGIN, HandleChatterBegin)
	EVENT_MANAGER:RegisterForEvent(LazyHorseFeed.name, EVENT_STABLE_INTERACT_START, HandleStableOpen)
	LazyHorseFeed.savedvars = ZO_SavedVars:NewAccountWide("lazyhorsefeedsavedvars", LazyHorseFeed.version, nil, LazyHorseFeed.default)

	LazyHorseFeed.charSavedVars = ZO_SavedVars:NewCharacterIdSettings("lazyhorsefeedsavedvars",
	LazyHorseFeed.version, nil, LazyHorseFeed.savedvars.accountWideProfile) 

	local LAM = LibAddonMenu2
	LAM:RegisterAddonPanel("LazyHorseFeedPanel", panel)
	
	for i = 1, #trainPriorities do
		table.insert(options ,
			{
				type = "dropdown",
				name = "Train "..i..":",
				tooltip = "Select the training you want to complete "..i,
				choices = trainNames,
				getFunc = function() return trainNames[LazyHorseFeed:GetSettings().TrainOrder[i]] end,
				setFunc = function(value) 
					local TrainOrder = LazyHorseFeed:GetSettings().TrainOrder
					local newNum
					for k , v in pairs(trainNames) do
						if v==value then
							newNum = k
						end
					end
					local oldSpot 
					for i = 1, #LazyHorseFeed:GetSettings().TrainOrder do
						if TrainOrder[i] == newNum then
							oldSpot = i
						end
					end
					local currentPriority = TrainOrder[i]
					TrainOrder[i] = newNum
					TrainOrder[oldSpot] = currentPriority
					-- TrainOrder[i] = oldSpot
					-- TrainOrder[oldSpot] = oldNum
				end,
			}
		)
	end
	LAM:RegisterOptionControls("LazyHorseFeedPanel", options)
end

 
function LazyHorseFeed.OnAddOnLoaded(event, addonName)
	if addonName == LazyHorseFeed.name then
		LazyHorseFeed:Initialize()
	end
end
 
EVENT_MANAGER:RegisterForEvent(LazyHorseFeed.name, EVENT_ADD_ON_LOADED, LazyHorseFeed.OnAddOnLoaded)



--[[

@Dolgubon could it be a sync problem, where you may have to wait for a mail to be completely sent before moving on to other tasks? (like guild bank, where nothing works till it's actually finished an action)

manavortex @manavortex Mar 13 10:14
afaik the mailbox has an internal table, and that doesn't automatically get rebuilt when you delete a mail.
It might be that that gets knocked over

Baertram @Baertram Mar 13 10:26
Postmaster is able to mass take items from mails + delete them. So maybe look into this code or ask the dev.

Michael Auerswald @flipswitchingmonkey Mar 13 14:25
@Dolgubon found it, but it's not fully implemented yet, unfortunately. It has some nice functions in it already, but alas, no list of bosses or way to track them (yet)


]]